HighchartsChart class Widgets

Inheritance

Constructors

HighchartsChart(HighchartsOptions options, {Key? key, String? css, bool debug = kDebugMode, String? javaScript, List<String> javaScriptModules = const ['packages/highcharts_flutter/assets/highcharts/highcharts.js', 'packages/highcharts_flutter/assets/highcharts/highcharts-more.js', 'packages/highcharts_flutter/assets/highcharts/highcharts-3d.js', 'packages/highcharts_flutter/assets/highcharts/modules/solid-gauge.js', 'packages/highcharts_flutter/assets/highcharts/modules/annotations.js', 'packages/highcharts_flutter/assets/highcharts/modules/boost.js', 'packages/highcharts_flutter/assets/highcharts/modules/broken-axis.js', 'packages/highcharts_flutter/assets/highcharts/modules/data.js', 'packages/highcharts_flutter/assets/highcharts/modules/exporting.js', 'packages/highcharts_flutter/assets/highcharts/modules/offline-exporting.js', 'packages/highcharts_flutter/assets/highcharts/modules/export-data.js', 'packages/highcharts_flutter/assets/highcharts/modules/accessibility.js'], Map<String, void Function(Object?)> events = const {}, bool keepAlive = true, bool scrollParentOnWheel = true, Widget onError(HighchartsChart, Object?)?, FutureOr<void> onLoaded(HighchartsChart)?, Widget onLoading(HighchartsChart)?})

Properties

css → String?
final
debug → bool
Activate debug mode.
final
events → Map<String, void Function(Object?)>
Map of JavaScript events and callback functions to register.
final
exporting ↔ HighchartsExporting
latefinal
hashCode → int
The hash code for this object.
no setterinherited
javaScript → String?
Custom JavaScript to inject into the webView. This will be executed after Highcharts Flutter code, but before the initial chart update with the defined options.
final
javaScriptModules → List<String>
JavaScript modules to load; either code or URLs. Defaults to the basic set from code.highcharts.com for each product widget. This will be executed before Highcharts Flutter code.
final
keepAlive → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onError → Widget Function(HighchartsChart, Object?)?
final
onLoaded → FutureOr<void> Function(HighchartsChart)?
final
onLoading → Widget Function(HighchartsChart)?
final
options → HighchartsOptions
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollParentOnWheel → bool
Whether mouse-wheel/trackpad scrolling over the chart should be routed to the parent Scrollable instead of being consumed by the WebView.
final
view ↔ HighchartsView
latefinal

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
off<T>(String eventPath, HighchartsCallbackDart<T>? callback) → Future<void>
on<T>(String eventPath, HighchartsCallbackDart<T> callback) → Future<void>
refresh([bool redraw = true]) → void
Refresh the chart with the latest options
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited