HighchartsAccessibilityScreenReaderSectionOptions class

Accessibility options for the screen reader information sections added before and after the chart.

API Docs: https://api.highcharts.com/highcharts/accessibility.screenReaderSection

Inheritance

Constructors

HighchartsAccessibilityScreenReaderSectionOptions({String? afterChartFormat, HighchartsCallback? afterChartFormatter, String? axisRangeDateFormat, String? beforeChartFormat, HighchartsCallback? beforeChartFormatter, HighchartsCallback? onPlayAsSoundClick, HighchartsCallback? onViewDataTableClick})
Accessibility options for the screen reader information sections added before and after the chart.

Properties

afterChartFormat ↔ String?
Format for the screen reader information region after the chart. Analogous to beforeChartFormat.
getter/setter pair
afterChartFormatter ↔ HighchartsCallback?
A formatter function to create the HTML contents of the hidden screen reader information region after the chart. Analogous to beforeChartFormatter.
getter/setter pair
axisRangeDateFormat ↔ String?
Date format to use to describe range of datetime axes.
getter/setter pair
beforeChartFormat ↔ String?
Format for the screen reader information region before the chart. Supported HTML tags are <h1-6>, <p>, <div>, <a>, <ul>, <ol>, <li>, and <button>. Attributes are not supported, except for id on <div>, <a>, and <button>. Id is required on <a> and <button> in the format <tag id="abcd">. Numbers, lower- and uppercase letters, "-" and "#" are valid characters in IDs.
getter/setter pair
beforeChartFormatter ↔ HighchartsCallback?
A formatter function to create the HTML contents of the hidden screen reader information region before the chart. Receives one argument, chart, referring to the chart object. Should return a string with the HTML content of the region. By default this returns an automatic description of the chart based on beforeChartFormat.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onPlayAsSoundClick ↔ HighchartsCallback?
Function to run upon clicking the "Play as sound" button in the screen reader region.
getter/setter pair
onViewDataTableClick ↔ HighchartsCallback?
Function to run upon clicking the "View as Data Table" link in the screen reader region.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → String
Serializes the settings to a JSON string.
inherited
toOptionsJSON(StringBuffer buffer) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited