HighchartsAnnotationsLabelsControlPointsOptions class

Inheritance

Constructors

HighchartsAnnotationsLabelsControlPointsOptions({Map<String, dynamic>? events, double? height, HighchartsCallback? positioner, HighchartsAnnotationsControlPointStyleOptions? style, String? symbol, bool? visible, double? width})
The array of control points.

Properties

events ↔ Map<String, dynamic>?
Highcharts Options Widget.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
Highcharts Options Widget.
getter/setter pair
positioner ↔ HighchartsCallback?
Highcharts Options Widget.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ HighchartsAnnotationsControlPointStyleOptions?
Highcharts Options Widget.
getter/setter pair
symbol ↔ String?
Highcharts Options Widget.
getter/setter pair
visible ↔ bool?
Highcharts Options Widget.
getter/setter pair
width ↔ double?
Highcharts Options Widget.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → String
Serializes the settings to a JSON string.
inherited
toOptionsJSON(StringBuffer buffer) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited