HighchartsAnnotationsShapeOptions class

Options for annotation's shapes. Each shape inherits options from the shapeOptions object. An option from the shapeOptions can be overwritten by config for a specific shape.

API Docs: https://api.highcharts.com/highcharts/navigation.bindings.verticalLine.annotationsOptions.shapeOptions

Inheritance

Constructors

HighchartsAnnotationsShapeOptions({String? dashStyle, String? fill, double? height, double? r, double? ry, double? snap, String? src, String? stroke, double? strokeWidth, String? type, double? width, double? xAxis, double? yAxis})
Options for annotation's shapes. Each shape inherits options from the shapeOptions object. An option from the shapeOptions can be overwritten by config for a specific shape.

Properties

dashStyle ↔ String?
Name of the dash style to use for the shape's stroke.
getter/setter pair
fill ↔ String?
The color of the shape's fill.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
The height of the rect shape. Can be defined in pixels or yAxis units, if shapes.yAxis index is defined.
getter/setter pair
r ↔ double?
The radius of the circle shape. Can be defined in pixels or yAxis units, if shapes.yAxis index is defined.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ry ↔ double?
The radius of the ellipse shape in y direction. Can be defined in pixels or yAxis units, if shapes.yAxis index is defined.
getter/setter pair
snap ↔ double?
Defines additional snapping area around an annotation making this annotation to focus. Defined in pixels.
getter/setter pair
src ↔ String?
The URL for an image to use as the annotation shape. Note, type has to be set to 'image'.
getter/setter pair
stroke ↔ String?
The color of the shape's stroke.
getter/setter pair
strokeWidth ↔ double?
The pixel stroke width of the shape.
getter/setter pair
type ↔ String?
The type of the shape. Available options are circle, rect, ellipse and path.
getter/setter pair
width ↔ double?
The width of the rect shape. Can be defined in pixels or xAxis units, if shapes.xAxis index is defined.
getter/setter pair
xAxis ↔ double?
The xAxis index which should be used for annotation's sizes and points coordinates conversion.
getter/setter pair
yAxis ↔ double?
The yAxis index which should be used for annotation's sizes and points coordinates conversion.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → String
Serializes the settings to a JSON string.
inherited
toOptionsJSON(StringBuffer buffer) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited