HighchartsBoxPlotSeries class Series

A boxplot series. If the type option is not specified, it is inherited from chart.type.

Configuration options for the series are given in three levels:

  1. Options for all series in a chart are defined in the plotOptions.series object.
  2. Options for all boxplot series are defined in plotOptions.boxplot.
  3. Options for one single series are given in the series instance array.

API Docs: https://api.highcharts.com/highcharts/series.boxplot

Inheritance

Constructors

HighchartsBoxPlotSeries({List<List>? data, String? name, HighchartsBoxPlotSeriesOptions? options, List<HighchartsBoxPlotSeriesDataOptions>? dataPoints})
A boxplot series. If the type option is not specified, it is inherited from chart.type.

Properties

data ↔ List<List>?
An array of data points for the series. For the boxplot series type, points can be given in the following ways:
getter/setter pair
dataPoints ↔ List<HighchartsBoxPlotSeriesDataOptions>?
List of data point objects for the HighchartsBoxPlotSeries series.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the series as shown in the legend, tooltip etc. If a dataTable and dataMapping are used, the name defaults to the id of the primary data table column. Otherwise, it defaults to "Series {n}", where n is the index of the series, starting at 1.
getter/setter pair
options ↔ HighchartsBoxPlotSeriesOptions?
Configuration options for the HighchartsBoxPlotSeries.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String
getter/setter pairinherited-setteroverride-getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → String
Serializes the settings to a JSON string.
inherited
toOptionsJSON(StringBuffer buffer) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited