options/highcharts_box_plot_series_data_data_labels_options library

Classes

HighchartsBoxPlotSeriesDataDataLabelsOptions
Individual data label for each point. The options are the same as the ones for plotOptions.series.dataLabels with exception of zIndex which is applied on the data label's parent group.
HighchartsSeriesDataLabelsAnimationOptions
Enable or disable the initial animation when a series is displayed for the dataLabels. The animation can also be set as a configuration object. Please note that this option only applies to the initial animation.
HighchartsSeriesDataLabelsFilterOptions
A declarative filter to control of which data labels to display. The declarative filter is designed for use when callback functions are not available, like when the chart options require a pure JSON structure or for use with graphical editors. For programmatic control, use the formatter instead, and return undefined to disable a single data label.
HighchartsSeriesDataLabelsTextPathOptions
Options for a label text which should follow marker's shape. Border and background are disabled for a label that follows a path.