padding property

List<double>? padding
getter/setter pair

When either the borderWidth or the backgroundColor is set, this is the padding within the box.

An array of numbers sets padding for the respective sides. An array of two numbers repeats the values for the horizontal and vertical sides.

API Docs: https://api.highcharts.com/highcharts/series.boxplot.dataLabels.padding

Implementation

List<double>? padding;