HighchartsBoxPlotSeriesDataOptions class

An array of data points for the series. For the boxplot series type, points can be given in the following ways:

  1. An array of arrays with 6 or 5 values. In this case, the values correspond to x,low,q1,median,q3,high. If the first value is a string, it is applied as the name of the point, and the x value is inferred. The x value can also be omitted, in which case the inner arrays should be of length 5. Then the x value is automatically calculated, either starting at 0 and incremented by 1, or from pointStart and pointInterval given in the series options.

  2. An array of objects with named values. The following snippet shows only a few settings, see the complete options set below. If the total number of data points exceeds the series' turboThreshold, this option is not available.

API Docs: https://api.highcharts.com/highcharts/series.boxplot.data

Inheritance

Constructors

HighchartsBoxPlotSeriesDataOptions({HighchartsBoxPlotSeriesDataAccessibilityOptions? accessibility, String? boxDashStyle, String? className, String? color, double? colorIndex, Map<String, dynamic>? custom, List<HighchartsBoxPlotSeriesDataDataLabelsOptions>? dataLabels, HighchartsBoxPlotSeriesDataDragDropOptions? dragDrop, String? drilldown, HighchartsBoxPlotSeriesDataEventsOptions? events, double? high, String? id, double? labelrank, double? low, double? median, String? medianDashStyle, String? name, double? q1, double? q3, bool? selected, String? stemDashStyle, String? whiskerDashStyle, dynamic x, double? y})
An array of data points for the series. For the boxplot series type, points can be given in the following ways:

Properties

accessibility ↔ HighchartsBoxPlotSeriesDataAccessibilityOptions?
Accessibility options for a data point.
getter/setter pair
boxDashStyle ↔ String?
The dash style of the box.
getter/setter pair
className ↔ String?
An additional, individual class name for the data point's graphic representation. Changes to a point's color will also be reflected in a chart's legend and tooltip.
getter/setter pair
color ↔ String?
Individual color for the point. By default the color is pulled from the global colors array.
getter/setter pair
colorIndex ↔ double?
A specific color index to use for the point, so its graphic representations are given the class name highcharts-color-{n}. In styled mode this will change the color of the graphic. In non-styled mode, the color is set by the fill attribute, so the change in class name won't have a visual effect by default.
getter/setter pair
custom ↔ Map<String, dynamic>?
A reserved subspace to store options and values for customized functionality. Here you can add additional data for your own event callbacks and formatter callbacks.
getter/setter pair
dataLabels ↔ List<HighchartsBoxPlotSeriesDataDataLabelsOptions>?
Individual data label for each point. The options are the same as the ones for plotOptions.series.dataLabels with exception of zIndex which is applied on the data label's parent group.
getter/setter pair
dragDrop ↔ HighchartsBoxPlotSeriesDataDragDropOptions?
Point specific options for the draggable-points module. Overrides options on series.dragDrop.
getter/setter pair
drilldown ↔ String?
The id of a series in the drilldown.series array to use for a drilldown for this point.
getter/setter pair
events ↔ HighchartsBoxPlotSeriesDataEventsOptions?
The individual point events.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
high ↔ double?
The high value for each data point, signifying the highest value in the sample set. The top whisker is drawn here.
getter/setter pair
id ↔ String?
An id for the point. This can be used after render time to get a pointer to the point object through chart.get().
getter/setter pair
labelrank ↔ double?
The rank for all this point's data labels in case of collision. If two data labels are about to overlap, only the one with the highest labelrank will be drawn.
getter/setter pair
low ↔ double?
The low value for each data point, signifying the lowest value in the sample set. The bottom whisker is drawn here.
getter/setter pair
median ↔ double?
The median for each data point. This is drawn as a line through the middle area of the box.
getter/setter pair
medianDashStyle ↔ String?
The dash style of the median.
getter/setter pair
name ↔ String?
The name of the point as shown in the legend, tooltip, dataLabels, etc.
getter/setter pair
q1 ↔ double?
The lower quartile for each data point. This is the bottom of the box.
getter/setter pair
q3 ↔ double?
The higher quartile for each data point. This is the top of the box.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected ↔ bool?
Whether the data point is selected initially.
getter/setter pair
stemDashStyle ↔ String?
The dash style of the stem.
getter/setter pair
whiskerDashStyle ↔ String?
The dash style of the whiskers.
getter/setter pair
x ↔ dynamic
The x value of the point.
getter/setter pair
y ↔ double?
The y value of the point.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → String
Serializes the settings to a JSON string.
inherited
toOptionsJSON(StringBuffer buffer) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited