nullInteraction property
Whether or not data-points with the value of null should be interactive.
When this is set to true, tooltips may highlight these points, and this
option also enables keyboard navigation for such points. Format options
for such points include nullFormat and
nullFormatter. Works for these series:
line, spline, area, area-spline, column, bar, and
timeline.
API Docs: https://api.highcharts.com/highcharts/series.boxplot.nullInteraction
Implementation
bool? nullInteraction;