options/highcharts_chart_options
library
Classes
-
HighchartsChart3DFrameBackOptions
-
The back side of the frame around a 3D chart.
-
HighchartsChart3DFrameBottomOptions
-
The bottom of the frame around a 3D chart.
-
HighchartsChart3DFrameFrontOptions
-
The front of the frame around a 3D chart.
-
HighchartsChart3DFrameLeftOptions
-
The left side of the frame around a 3D chart.
-
HighchartsChart3DFrameOptions
-
Provides the option to draw a frame around the charts by
defining a bottom, front and back panel.
-
HighchartsChart3DFrameRightOptions
-
The right of the frame around a 3D chart.
-
HighchartsChart3DFrameSideOptions
-
Note: As of v5.0.12,
frame.left or frame.right should be used instead.
-
HighchartsChart3DFrameTopOptions
-
The top of the frame around a 3D chart.
-
HighchartsChart3DOptions
-
Options to render charts in 3 dimensions. This feature requires
highcharts-3d.js, found in the download package or online at
code.highcharts.com/highcharts-3d.js.
-
HighchartsChartEventsOptions
-
Event listeners for the chart.
-
HighchartsChartOptions
-
General options for the chart.
-
HighchartsChartPanningOptions
-
Allow panning in a chart. Best used with panKey
to combine zooming and panning.
-
HighchartsChartParallelAxesLabelsOptions
-
Highcharts Options Widget.
-
HighchartsChartParallelAxesOptions
-
Common options for all yAxes rendered in a parallel coordinates plot.
This feature requires
modules/parallel-coordinates.js.
-
HighchartsChartParallelAxesTitleOptions
-
Visually the parallel coordinates titles are done through
xAxis.categories. All options for
xAxis.labels
applies to parallel coordinates titles. For example, to style
categories, use xAxis.labels.style.
-
HighchartsChartResetZoomButtonOptions
-
Deprecated. Use
chart.zooming.resetButton
instead.
-
HighchartsChartResetZoomButtonPositionOptions
-
The position of the button.
-
HighchartsChartResetZoomButtonThemeOptions
-
A collection of attributes for the button. The object takes SVG
attributes like
fill, stroke, stroke-width or r, the
border radius. The theme also supports style, a collection of
CSS properties for the text. Equivalent attributes for the hover
state are given in theme.states.hover.
-
HighchartsChartScrollablePlotAreaOptions
-
Options for a scrollable plot area. This feature provides a minimum size for
the plot area of the chart. If the size gets smaller than this, typically
on mobile devices, a native browser scrollbar is presented. This scrollbar
provides smooth scrolling for the contents of the plot area, whereas the
title, legend and unaffected axes are fixed.
-
HighchartsChartZoomingMouseWheelOptions
-
The mouse wheel zoom is a feature included in Highcharts Stock, but is also
available for Highcharts Core as a module. Zooming with the mouse wheel is
enabled by default in Highcharts Stock. In Highcharts Core it is enabled if
chart.zooming.type is set. It can be disabled by
setting this option to
false.
-
HighchartsChartZoomingOptions
-
Chart zooming options.
-
HighchartsChartZoomingResetButtonOptions
-
The button that appears after a selection zoom, allowing the user
to reset zoom.
-
HighchartsChartZoomingResetButtonPositionOptions
-
The position of the button.
-
HighchartsXAxisAccessibilityOptions
-
Accessibility options for an axis. Requires the accessibility module.
-
HighchartsXAxisCrosshairLabelOptions
-
A label on the axis next to the crosshair.
-
HighchartsXAxisCrosshairOptions
-
Configure a crosshair that follows either the mouse pointer or the
hovered point.
-
HighchartsXAxisDateTimeLabelFormatsDayOptions
-
Highcharts Options Widget.
-
HighchartsXAxisDateTimeLabelFormatsHourOptions
-
Highcharts Options Widget.
-
HighchartsXAxisDateTimeLabelFormatsMillisecondOptions
-
Highcharts Options Widget.
-
HighchartsXAxisDateTimeLabelFormatsMinuteOptions
-
Highcharts Options Widget.
-
HighchartsXAxisDateTimeLabelFormatsMonthOptions
-
Highcharts Options Widget.
-
HighchartsXAxisDateTimeLabelFormatsOptions
-
For a datetime axis, the scale will automatically adjust to the
appropriate unit. This member gives the default representations used
for each unit. For easier data interpretation,
hour, day, month
and year units can be used and formatted as boundary tick values.
Check boundaries map below to see where to format boundary ticks on
given main time units.
-
HighchartsXAxisDateTimeLabelFormatsSecondOptions
-
Highcharts Options Widget.
-
HighchartsXAxisDateTimeLabelFormatsWeekOptions
-
Highcharts Options Widget.
-
HighchartsXAxisDateTimeLabelFormatsYearOptions
-
Highcharts Options Widget.
-
HighchartsXAxisEventsOptions
-
Event handlers for the axis.
-
HighchartsXAxisLabelsStyleOptions
-
CSS styles for the label. Use
lineClamp to control wrapping of
category labels. Use textOverflow: 'none' to prevent ellipsis
(dots).
-
HighchartsXAxisTitleStyleOptions
-
CSS styles for the title. If the title text is longer than the
axis length, it will wrap to multiple lines by default. This can
be customized by setting the
lineClamp property, by setting a
specific width or by setting whiteSpace: 'nowrap'.
-
HighchartsYAxisStackShadowOptions
-
Relevant only for pictorial series. The
stackShadow forms the background of
stacked points. Requires series.stacking to be defined.