HighchartsChartParallelAxesOptions class

Common options for all yAxes rendered in a parallel coordinates plot. This feature requires modules/parallel-coordinates.js.

The default options are:

API Docs: https://api.highcharts.com/highcharts/chart.parallelAxes

Inheritance

Constructors

HighchartsChartParallelAxesOptions({HighchartsXAxisAccessibilityOptions? accessibility, bool? alignTicks, bool? allowDecimals, List<String>? categories, double? ceiling, String? className, HighchartsXAxisCrosshairOptions? crosshair, double? crossing, HighchartsXAxisDateTimeLabelFormatsOptions? dateTimeLabelFormats, bool? endOnTick, HighchartsXAxisEventsOptions? events, double? floor, double? gridZIndex, dynamic height, HighchartsChartParallelAxesLabelsOptions? labels, dynamic left, String? lineColor, double? lineWidth, double? linkedTo, double? margin, dynamic max, double? maxPadding, dynamic min, double? minPadding, double? minRange, double? minTickInterval, String? minorTickColor, String? minorTickInterval, double? minorTickLength, String? minorTickPosition, double? minorTickWidth, bool? minorTicks, double? minorTicksPerMajor, double? offset, bool? opposite, double? pane, bool? panningEnabled, bool? reversed, bool? reversedStacks, bool? showEmpty, bool? showFirstLabel, bool? showLastLabel, double? softMax, double? softMin, HighchartsYAxisStackShadowOptions? stackShadow, double? startOfWeek, bool? startOnTick, double? staticScale, double? tickAmount, String? tickColor, double? tickInterval, double? tickLength, double? tickPixelInterval, String? tickPosition, HighchartsCallback? tickPositioner, List<double>? tickPositions, double? tickWidth, String? tickmarkPlacement, HighchartsChartParallelAxesTitleOptions? title, String? tooltipValueFormat, dynamic top, String? type, bool? uniqueNames, List<List>? units, bool? visible, dynamic width, double? zIndex, bool? zoomEnabled})
Common options for all yAxes rendered in a parallel coordinates plot. This feature requires modules/parallel-coordinates.js.

Properties

accessibility ↔ HighchartsXAxisAccessibilityOptions?
Accessibility options for an axis. Requires the accessibility module.
getter/setter pair
alignTicks ↔ bool?
When using multiple axis, the ticks of two or more opposite axes will automatically be aligned by adding ticks to the axis or axes with the least ticks, as if tickAmount were specified.
getter/setter pair
allowDecimals ↔ bool?
Whether to allow decimals in this axis' ticks. When counting integers, like persons or hits on a web page, decimals should be avoided in the labels. By default, decimals are allowed on small scale axes.
getter/setter pair
categories ↔ List<String>?
If categories are present for the xAxis, names are used instead of numbers for that axis.
getter/setter pair
ceiling ↔ double?
The highest allowed value for automatically computed axis extremes.
getter/setter pair
className ↔ String?
A class name that opens for styling the axis by CSS, especially in Highcharts styled mode. The class name is applied to group elements for the grid, axis elements and labels.
getter/setter pair
crosshair ↔ HighchartsXAxisCrosshairOptions?
Configure a crosshair that follows either the mouse pointer or the hovered point.
getter/setter pair
crossing ↔ double?
The value on a perpendicular axis where this axis should cross. This is typically used on mathematical plots where the axes cross at 0. When crossing is set, space will not be reserved at the sides of the chart for axis labels and title, so those may be clipped. In this case it is better to place the axes without the crossing option.
getter/setter pair
dateTimeLabelFormats ↔ HighchartsXAxisDateTimeLabelFormatsOptions?
For a datetime axis, the scale will automatically adjust to the appropriate unit. This member gives the default representations used for each unit. For easier data interpretation, hour, day, month and year units can be used and formatted as boundary tick values. Check boundaries map below to see where to format boundary ticks on given main time units.
getter/setter pair
endOnTick ↔ bool?
Whether to force the axis to end on a tick. Use this option with the maxPadding option to control the axis end.
getter/setter pair
events ↔ HighchartsXAxisEventsOptions?
Event handlers for the axis.
getter/setter pair
floor ↔ double?
The lowest allowed value for automatically computed axis extremes.
getter/setter pair
gridZIndex ↔ double?
The Z index of the grid lines.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ dynamic
The height of the Y axis. If it's a number, it is interpreted as pixels.
getter/setter pair
labels ↔ HighchartsChartParallelAxesLabelsOptions?
Highcharts Options Widget.
getter/setter pair
left ↔ dynamic
The left position as the horizontal axis. If it's a number, it is interpreted as pixel position relative to the chart.
getter/setter pair
lineColor ↔ String?
The color of the line marking the axis itself.
getter/setter pair
lineWidth ↔ double?
Highcharts Options Widget.
getter/setter pair
linkedTo ↔ double?
Index of another axis that this axis is linked to. When an axis is linked to a master axis, it will take the same extremes as the master, but as assigned by min or max or by setExtremes. It can be used to show additional info, or to ease reading the chart by duplicating the scales.
getter/setter pair
margin ↔ double?
If there are multiple axes on the same side of the chart, the pixel margin between the axes. Defaults to 0 on vertical axes, 15 on horizontal axes.
getter/setter pair
max ↔ dynamic
Highcharts Options Widget.
getter/setter pair
maxPadding ↔ double?
Padding of the max value relative to the length of the axis. A padding of 0.05 will make a 100px axis 5px longer. This is useful when you don't want the highest data value to appear on the edge of the plot area. When the axis' max option is set or a max extreme is set using axis.setExtremes(), the maxPadding will be ignored.
getter/setter pair
min ↔ dynamic
Highcharts Options Widget.
getter/setter pair
minorTickColor ↔ String?
Color for the minor tick marks.
getter/setter pair
minorTickInterval ↔ String?
Specific tick interval in axis units for the minor ticks. On a linear axis, if "auto", the minor tick interval is calculated as a fifth of the tickInterval. If undefined, minor ticks are not shown.
getter/setter pair
minorTickLength ↔ double?
The pixel length of the minor tick marks.
getter/setter pair
minorTickPosition ↔ String?
The position of the minor tick marks relative to the axis line. Can be one of inside and outside.
getter/setter pair
minorTicks ↔ bool?
Enable or disable minor ticks. The interval between the minor ticks can be controlled either by the minorTicksPerMajor setting, or as an absolute minorTickInterval value.
getter/setter pair
minorTicksPerMajor ↔ double?
The number of minor ticks per major tick. Works for linear, logarithmic and datetime axes.
getter/setter pair
minorTickWidth ↔ double?
The pixel width of the minor tick mark.
getter/setter pair
minPadding ↔ double?
Padding of the min value relative to the length of the axis. A padding of 0.05 will make a 100px axis 5px longer. This is useful when you don't want the lowest data value to appear on the edge of the plot area. When the axis' min option is set or a max extreme is set using axis.setExtremes(), the maxPadding will be ignored.
getter/setter pair
minRange ↔ double?
The minimum range to display on this axis. The entire axis will not be allowed to span over a smaller interval than this. For example, for a datetime axis the main unit is milliseconds. If minRange is set to 3600000, you can't zoom in more than to one hour.
getter/setter pair
minTickInterval ↔ double?
The minimum tick interval allowed in axis values. For example on zooming in on an axis with daily data, this can be used to prevent the axis from showing hours. Defaults to the closest distance between two points on the axis.
getter/setter pair
offset ↔ double?
Highcharts Options Widget.
getter/setter pair
opposite ↔ bool?
Highcharts Options Widget.
getter/setter pair
pane ↔ double?
Refers to the index in the panes array. Used for circular gauges and polar charts. When the option is not set then first pane will be used.
getter/setter pair
panningEnabled ↔ bool?
Whether to pan axis. If chart.panning is enabled, the option allows to disable panning on an individual axis.
getter/setter pair
reversed ↔ bool?
Whether to reverse the axis so that the highest number is closest to the origin.
getter/setter pair
reversedStacks ↔ bool?
If true, the first series in a stack will be drawn on top in a positive, non-reversed Y axis. If false, the first series is in the base of the stack.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showEmpty ↔ bool?
Whether to show the axis line and title when the axis has no data.
getter/setter pair
showFirstLabel ↔ bool?
Whether to show the first tick label.
getter/setter pair
showLastLabel ↔ bool?
Whether to show the last tick label.
getter/setter pair
softMax ↔ double?
A soft maximum for the axis. If the series data maximum is less than this, the axis will stay at this maximum, but if the series data maximum is higher, the axis will flex to show all data.
getter/setter pair
softMin ↔ double?
A soft minimum for the axis. If the series data minimum is greater than this, the axis will stay at this minimum, but if the series data minimum is lower, the axis will flex to show all data.
getter/setter pair
stackShadow ↔ HighchartsYAxisStackShadowOptions?
Relevant only for pictorial series. The stackShadow forms the background of stacked points. Requires series.stacking to be defined.
getter/setter pair
startOfWeek ↔ double?
For datetime axes, this decides where to put the tick between weeks. 0 = Sunday, 1 = Monday.
getter/setter pair
startOnTick ↔ bool?
Whether to force the axis to start on a tick. Use this option with the maxPadding option to control the axis start.
getter/setter pair
staticScale ↔ double?
For vertical axes only. Setting the static scale ensures that each tick unit is translated into a fixed pixel height. For example, setting the static scale to 24 results in each Y axis category taking up 24 pixels, and the height of the chart adjusts. Adding or removing items will make the chart resize.
getter/setter pair
tickAmount ↔ double?
The amount of ticks to draw on the axis. This opens up for aligning the ticks of multiple charts or panes within a chart. This option overrides the tickPixelInterval option.
getter/setter pair
tickColor ↔ String?
Color for the main tick marks.
getter/setter pair
tickInterval ↔ double?
The interval of the tick marks in axis units. When undefined, the tick interval is computed to approximately follow the tickPixelInterval on linear and datetime axes. On categorized axes, a undefined tickInterval will default to 1, one category. Note that datetime axes are based on milliseconds, so for example an interval of one day is expressed as 24 * 3600 * 1000.
getter/setter pair
tickLength ↔ double?
The pixel length of the main tick marks.
getter/setter pair
tickmarkPlacement ↔ String?
For categorized axes only. If on the tick mark is placed in the center of the category, if between the tick mark is placed between categories. The default is between if the tickInterval is 1, else on. In order to render tick marks on a category axis it is necessary to provide a tickWidth.
getter/setter pair
tickPixelInterval ↔ double?
Highcharts Options Widget.
getter/setter pair
tickPosition ↔ String?
The position of the major tick marks relative to the axis line. Can be one of inside and outside.
getter/setter pair
tickPositioner ↔ HighchartsCallback?
A callback function returning array defining where the ticks are laid out on the axis. This overrides the default behavior of tickPixelInterval and tickInterval. The automatic tick positions are accessible through this.tickPositions and can be modified by the callback. Since v12.6.0, the callback also receives ctx as the third argument, so that arrow functions can access the same context as regular functions using this.
getter/setter pair
tickPositions ↔ List<double>?
An array defining where the ticks are laid out on the axis. This overrides the default behavior of tickPixelInterval and tickInterval.
getter/setter pair
tickWidth ↔ double?
The pixel width of the major tick marks.
getter/setter pair
title ↔ HighchartsChartParallelAxesTitleOptions?
Visually the parallel coordinates titles are done through xAxis.categories. All options for xAxis.labels applies to parallel coordinates titles. For example, to style categories, use xAxis.labels.style.
getter/setter pair
tooltipValueFormat ↔ String?
Parallel coordinates only. Format that will be used for point.y and available in tooltip.pointFormat as {point.formattedValue}. If not set, {point.formattedValue} will use other options, in this order:
getter/setter pair
top ↔ dynamic
The top position of the Y axis. If it's a number, it is interpreted as pixel position relative to the chart.
getter/setter pair
type ↔ String?
The type of axis. Can be one of linear, logarithmic, datetime, category or treegrid. Defaults to treegrid for Gantt charts, linear for other chart types.
getter/setter pair
uniqueNames ↔ bool?
Applies only when the axis type is category. When uniqueNames is true, points are placed on the X axis according to their names. If the same point name is repeated in the same or another series, the point is placed on the same X position as other points of the same name. When uniqueNames is false, the points are laid out in increasing X positions regardless of their names, and the X axis category will take the name of the last point in each position.
getter/setter pair
units ↔ List<List>?
Datetime axis only. An array determining what time intervals the ticks are allowed to fall on. Each array item is an array where the first value is the time unit and the second value another array of allowed multiples.
getter/setter pair
visible ↔ bool?
Whether axis, including axis title, line, ticks and labels, should be visible.
getter/setter pair
width ↔ dynamic
The width as the horizontal axis. If it's a number, it is interpreted as pixels.
getter/setter pair
zIndex ↔ double?
The Z index for the axis group.
getter/setter pair
zoomEnabled ↔ bool?
Whether to zoom axis. If chart.zoomType is set, the option allows to disable zooming on an individual axis.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → String
Serializes the settings to a JSON string.
inherited
toOptionsJSON(StringBuffer buffer) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited