dateTimeLabelFormats property

HighchartsXAxisDateTimeLabelFormatsOptions? dateTimeLabelFormats
getter/setter pair

For a datetime axis, the scale will automatically adjust to the appropriate unit. This member gives the default representations used for each unit. For easier data interpretation, hour, day, month and year units can be used and formatted as boundary tick values. Check boundaries map below to see where to format boundary ticks on given main time units.

For an overview of the date time label formats configuration, see dateFormat.

Defaults to:

API Docs: https://api.highcharts.com/highcharts/chart.parallelAxes.dateTimeLabelFormats

Implementation

HighchartsXAxisDateTimeLabelFormatsOptions? dateTimeLabelFormats;