HighchartsChartScrollablePlotAreaOptions class

Options for a scrollable plot area. This feature provides a minimum size for the plot area of the chart. If the size gets smaller than this, typically on mobile devices, a native browser scrollbar is presented. This scrollbar provides smooth scrolling for the contents of the plot area, whereas the title, legend and unaffected axes are fixed.

Since v7.1.2, a scrollable plot area can be defined for either horizontal or vertical scrolling, depending on whether the minWidth or minHeight option is set.

Note: Because native browser scrollbars are used, they may overlap with fixed chart elements such as credits or the chart border. To avoid this collision, it is recommended to manually add extra space to the corresponding side using chart.spacingBottom (for horizontal scrollbars) or chart.spacingRight (for vertical scrollbars).

API Docs: https://api.highcharts.com/highcharts/chart.scrollablePlotArea

Inheritance

Constructors

HighchartsChartScrollablePlotAreaOptions({double? minHeight, double? minWidth, double? opacity, double? scrollPositionX, double? scrollPositionY})
Options for a scrollable plot area. This feature provides a minimum size for the plot area of the chart. If the size gets smaller than this, typically on mobile devices, a native browser scrollbar is presented. This scrollbar provides smooth scrolling for the contents of the plot area, whereas the title, legend and unaffected axes are fixed.

Properties

hashCode → int
The hash code for this object.
no setterinherited
minHeight ↔ double?
The minimum height for the plot area. If it gets smaller than this, the plot area will become scrollable.
getter/setter pair
minWidth ↔ double?
The minimum width for the plot area. If it gets smaller than this, the plot area will become scrollable.
getter/setter pair
opacity ↔ double?
The opacity of mask applied on one of the sides of the plot area.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollPositionX ↔ double?
The initial scrolling position of the scrollable plot area. Ranges from 0 to 1, where 0 aligns the plot area to the left and 1 aligns it to the right. Typically we would use 1 if the chart has right aligned Y axes.
getter/setter pair
scrollPositionY ↔ double?
The initial scrolling position of the scrollable plot area. Ranges from 0 to 1, where 0 aligns the plot area to the top and 1 aligns it to the bottom.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → String
Serializes the settings to a JSON string.
inherited
toOptionsJSON(StringBuffer buffer) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited