HighchartsDataTableOptions class
Options for one or many chart-level data tables. The dataTable option,
or its array members, can be either configuration objects or instances of
the DataTable class. If a DataTable instance is passed, it
will be used directly. If a configuration object is passed, a new
DataTable instance will be created based on the provided
configuration.
The data table is mapped to the series data points based on the
series.dataMapping option, unless the
column keys match the point property names (x, y etc.), in which case
the mapping is automatic.
- Inheritance
-
- Object
- HighchartsOptionsBase
- HighchartsDataTableOptions
Constructors
- HighchartsDataTableOptions({dynamic columns, String? id})
-
Options for one or many chart-level data tables. The
dataTableoption, or its array members, can be either configuration objects or instances of theDataTableclass. If aDataTableinstance is passed, it will be used directly. If a configuration object is passed, a newDataTableinstance will be created based on the provided configuration.
Properties
- columns ↔ dynamic
-
A collection of data table columns defined by a object where the key is the
column ID and the value is an array of the column values. Typed arrays are
supported.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Custom ID to identify the new DataTable instance.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON(
) → String -
Serializes the settings to a JSON string.
inherited
-
toOptionsJSON(
StringBuffer buffer) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited