padding property

double? padding
getter/setter pair

The padding inside the plot area when auto fitting to the map bounds. A number signifies pixels, and a percentage is relative to the plot area size.

An array sets individual padding for the sides in the order top, right, bottom, left.

API Docs: https://api.highcharts.com/highcharts/mapView.padding

Implementation

double? padding;