HighchartsNavigationButtonOptions class

A collection of options for buttons appearing in the exporting module.

In styled mode, the buttons are styled with the .highcharts-contextbutton and .highcharts-button-symbol classes.

API Docs: https://api.highcharts.com/highcharts/navigation.buttonOptions

Inheritance

Constructors

HighchartsNavigationButtonOptions({String? align, double? buttonSpacing, bool? enabled, double? height, String? symbolFill, double? symbolSize, String? symbolStroke, double? symbolStrokeWidth, double? symbolX, double? symbolY, String? text, HighchartsNavigationButtonThemeOptions? theme, bool? useHTML, String? verticalAlign, double? width, double? y})
A collection of options for buttons appearing in the exporting module.

Properties

align ↔ String?
Alignment for the buttons.
getter/setter pair
buttonSpacing ↔ double?
The pixel spacing between buttons, and between the context button and the title.
getter/setter pair
enabled ↔ bool?
Whether to enable buttons.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
Pixel height of the buttons.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
symbolFill ↔ String?
Fill color for the symbol within the button.
getter/setter pair
symbolSize ↔ double?
The pixel size of the symbol on the button.
getter/setter pair
symbolStroke ↔ String?
The color of the symbol's stroke or line.
getter/setter pair
symbolStrokeWidth ↔ double?
The pixel stroke width of the symbol on the button.
getter/setter pair
symbolX ↔ double?
The x position of the center of the symbol inside the button.
getter/setter pair
symbolY ↔ double?
The y position of the center of the symbol inside the button.
getter/setter pair
text ↔ String?
A text string to add to the individual button.
getter/setter pair
theme ↔ HighchartsNavigationButtonThemeOptions?
A configuration object for the button theme. The object accepts SVG properties like stroke-width, stroke and fill. Tri-state button styles are supported by the states.hover and states.select objects.
getter/setter pair
useHTML ↔ bool?
Whether to use HTML for rendering the button. HTML allows for things like inline CSS or image-based icons.
getter/setter pair
verticalAlign ↔ String?
The vertical alignment of the buttons. Can be one of "top", "middle" or "bottom".
getter/setter pair
width ↔ double?
The pixel width of the button.
getter/setter pair
y ↔ double?
The vertical offset of the button's position relative to its verticalAlign. By default adjusted for the chart title alignment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → String
Serializes the settings to a JSON string.
inherited
toOptionsJSON(StringBuffer buffer) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited