HighchartsNavigationButtonThemeOptions class

A configuration object for the button theme. The object accepts SVG properties like stroke-width, stroke and fill. Tri-state button styles are supported by the states.hover and states.select objects.

API Docs: https://api.highcharts.com/highcharts/navigation.buttonOptions.theme

Inheritance

Constructors

HighchartsNavigationButtonThemeOptions({String? fill, double? padding, HighchartsNavigationButtonThemeStatesOptions? states, String? stroke, String? strokeLinecap, Map<String, String>? style})
A configuration object for the button theme. The object accepts SVG properties like stroke-width, stroke and fill. Tri-state button styles are supported by the states.hover and states.select objects.

Properties

fill ↔ String?
The default fill exists only to capture hover events.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
padding ↔ double?
Padding for the button.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
states ↔ HighchartsNavigationButtonThemeStatesOptions?
Tri-state button styles.
getter/setter pair
stroke ↔ String?
Default stroke for the buttons.
getter/setter pair
strokeLinecap ↔ String?
Default stroke linecap for the buttons.
getter/setter pair
style ↔ Map<String, String>?
CSS styling for the button's text or symbol.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJSON() → String
Serializes the settings to a JSON string.
inherited
toOptionsJSON(StringBuffer buffer) → void
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited