dataTable property

HighchartsDataTableOptions? dataTable
getter/setter pair

Options for one or many chart-level data tables. The dataTable option, or its array members, can be either configuration objects or instances of the DataTable class. If a DataTable instance is passed, it will be used directly. If a configuration object is passed, a new DataTable instance will be created based on the provided configuration.

The data table is mapped to the series data points based on the series.dataMapping option, unless the column keys match the point property names (x, y etc.), in which case the mapping is automatic.

API Docs: https://api.highcharts.com/highcharts/dataTable

Implementation

HighchartsDataTableOptions? dataTable;