HighchartsPlotOptions constructor

HighchartsPlotOptions({
  1. HighchartsABandsSeriesOptions? abands,
  2. HighchartsADSeriesOptions? ad,
  3. HighchartsAOSeriesOptions? ao,
  4. HighchartsAPOSeriesOptions? apo,
  5. HighchartsArcDiagramSeriesOptions? arcdiagram,
  6. HighchartsAreaSeriesOptions? area,
  7. HighchartsAreaRangeSeriesOptions? arearange,
  8. HighchartsAreaSplineSeriesOptions? areaspline,
  9. HighchartsAreaSplineRangeSeriesOptions? areasplinerange,
  10. HighchartsAroonSeriesOptions? aroon,
  11. HighchartsAroonOscillatorSeriesOptions? aroonoscillator,
  12. HighchartsATRSeriesOptions? atr,
  13. HighchartsBarSeriesOptions? bar,
  14. HighchartsBBSeriesOptions? bb,
  15. HighchartsBellcurveSeriesOptions? bellcurve,
  16. HighchartsBoxPlotSeriesOptions? boxplot,
  17. HighchartsBubbleSeriesOptions? bubble,
  18. HighchartsBulletSeriesOptions? bullet,
  19. HighchartsCandlestickSeriesOptions? candlestick,
  20. HighchartsCCISeriesOptions? cci,
  21. HighchartsChaikinSeriesOptions? chaikin,
  22. HighchartsCMFSeriesOptions? cmf,
  23. HighchartsCMOSeriesOptions? cmo,
  24. HighchartsColumnSeriesOptions? column,
  25. HighchartsColumnPyramidSeriesOptions? columnpyramid,
  26. HighchartsColumnRangeSeriesOptions? columnrange,
  27. HighchartsContourSeriesOptions? contour,
  28. HighchartsCylinderSeriesOptions? cylinder,
  29. HighchartsDEMASeriesOptions? dema,
  30. HighchartsDependencyWheelSeriesOptions? dependencywheel,
  31. HighchartsDisparityIndexSeriesOptions? disparityindex,
  32. HighchartsDMISeriesOptions? dmi,
  33. HighchartsDPOSeriesOptions? dpo,
  34. HighchartsDumbbellSeriesOptions? dumbbell,
  35. HighchartsEMASeriesOptions? ema,
  36. HighchartsErrorBarSeriesOptions? errorbar,
  37. HighchartsFlagsSeriesOptions? flags,
  38. HighchartsFlowMapSeriesOptions? flowmap,
  39. HighchartsFunnelSeriesOptions? funnel,
  40. HighchartsFunnel3DSeriesOptions? funnel3d,
  41. HighchartsGanttSeriesOptions? gantt,
  42. HighchartsGaugeSeriesOptions? gauge,
  43. HighchartsGeoHeatmapSeriesOptions? geoheatmap,
  44. HighchartsHeatmapSeriesOptions? heatmap,
  45. HighchartsHeikinAshiSeriesOptions? heikinashi,
  46. HighchartsHistogramSeriesOptions? histogram,
  47. HighchartsHLCSeriesOptions? hlc,
  48. HighchartsHollowcandlestickSeriesOptions? hollowcandlestick,
  49. HighchartsIKHSeriesOptions? ikh,
  50. HighchartsItemSeriesOptions? item,
  51. HighchartsKeltnerChannelsSeriesOptions? keltnerchannels,
  52. HighchartsKlingerSeriesOptions? klinger,
  53. HighchartsLineSeriesOptions? line,
  54. HighchartsLinearRegressionSeriesOptions? linearregression,
  55. HighchartsLinearRegressionAngleSeriesOptions? linearregressionangle,
  56. HighchartsLinearRegressionInterceptSeriesOptions? linearregressionintercept,
  57. HighchartsLinearregressionslopeSeriesOptions? linearregressionslope,
  58. HighchartsLollipopSeriesOptions? lollipop,
  59. HighchartsMACDSeriesOptions? macd,
  60. HighchartsMapSeriesOptions? map,
  61. HighchartsMapBubbleSeriesOptions? mapbubble,
  62. HighchartsMapLineSeriesOptions? mapline,
  63. HighchartsMapPointSeriesOptions? mappoint,
  64. HighchartsMFISeriesOptions? mfi,
  65. HighchartsMomentumSeriesOptions? momentum,
  66. HighchartsNATRSeriesOptions? natr,
  67. HighchartsNetworkgraphSeriesOptions? networkgraph,
  68. HighchartsOBVSeriesOptions? obv,
  69. HighchartsOHLCSeriesOptions? ohlc,
  70. HighchartsOrganizationSeriesOptions? organization,
  71. HighchartsPackedBubbleSeriesOptions? packedbubble,
  72. HighchartsParetoSeriesOptions? pareto,
  73. HighchartsPCSeriesOptions? pc,
  74. HighchartsPictorialSeriesOptions? pictorial,
  75. HighchartsPieSeriesOptions? pie,
  76. HighchartsPivotPointsSeriesOptions? pivotpoints,
  77. HighchartsPointandfigureSeriesOptions? pointandfigure,
  78. HighchartsPolygonSeriesOptions? polygon,
  79. HighchartsPPOSeriesOptions? ppo,
  80. HighchartsPriceEnvelopesSeriesOptions? priceenvelopes,
  81. HighchartsPSARSeriesOptions? psar,
  82. HighchartsPyramidSeriesOptions? pyramid,
  83. HighchartsPyramid3DSeriesOptions? pyramid3d,
  84. HighchartsRenkoSeriesOptions? renko,
  85. HighchartsROCSeriesOptions? roc,
  86. HighchartsRSISeriesOptions? rsi,
  87. HighchartsSankeySeriesOptions? sankey,
  88. HighchartsScatterSeriesOptions? scatter,
  89. HighchartsScatter3DSeriesOptions? scatter3d,
  90. HighchartsSeriesOptions? series,
  91. HighchartsSlowStochasticSeriesOptions? slowstochastic,
  92. HighchartsSMASeriesOptions? sma,
  93. HighchartsSolidGaugeSeriesOptions? solidgauge,
  94. HighchartsSplineSeriesOptions? spline,
  95. HighchartsStochasticSeriesOptions? stochastic,
  96. HighchartsStreamgraphSeriesOptions? streamgraph,
  97. HighchartsSunburstSeriesOptions? sunburst,
  98. HighchartsSupertrendSeriesOptions? supertrend,
  99. HighchartsTEMASeriesOptions? tema,
  100. HighchartsTiledWebMapSeriesOptions? tiledwebmap,
  101. HighchartsTilemapSeriesOptions? tilemap,
  102. HighchartsTimelineSeriesOptions? timeline,
  103. HighchartsTreegraphSeriesOptions? treegraph,
  104. HighchartsTreemapSeriesOptions? treemap,
  105. HighchartsTrendlineSeriesOptions? trendline,
  106. HighchartsTRIXSeriesOptions? trix,
  107. HighchartsVariablePieSeriesOptions? variablepie,
  108. HighchartsVariwideSeriesOptions? variwide,
  109. HighchartsVBPSeriesOptions? vbp,
  110. HighchartsVectorSeriesOptions? vector,
  111. HighchartsVennSeriesOptions? venn,
  112. HighchartsVWAPSeriesOptions? vwap,
  113. HighchartsWaterfallSeriesOptions? waterfall,
  114. HighchartsWilliamsRSeriesOptions? williamsr,
  115. HighchartsWindbarbSeriesOptions? windbarb,
  116. HighchartsWMASeriesOptions? wma,
  117. HighchartsWordcloudSeriesOptions? wordcloud,
  118. HighchartsXRangeSeriesOptions? xrange,
  119. HighchartsZigzagSeriesOptions? zigzag,
})

The plotOptions is a wrapper object for config objects for each series type. The config objects for each series can also be overridden for each series item as given in the series array.

API Docs: https://api.highcharts.com/highcharts/plotOptions

Implementation

HighchartsPlotOptions(
    {this.abands,
    this.ad,
    this.ao,
    this.apo,
    this.arcdiagram,
    this.area,
    this.arearange,
    this.areaspline,
    this.areasplinerange,
    this.aroon,
    this.aroonoscillator,
    this.atr,
    this.bar,
    this.bb,
    this.bellcurve,
    this.boxplot,
    this.bubble,
    this.bullet,
    this.candlestick,
    this.cci,
    this.chaikin,
    this.cmf,
    this.cmo,
    this.column,
    this.columnpyramid,
    this.columnrange,
    this.contour,
    this.cylinder,
    this.dema,
    this.dependencywheel,
    this.disparityindex,
    this.dmi,
    this.dpo,
    this.dumbbell,
    this.ema,
    this.errorbar,
    this.flags,
    this.flowmap,
    this.funnel,
    this.funnel3d,
    this.gantt,
    this.gauge,
    this.geoheatmap,
    this.heatmap,
    this.heikinashi,
    this.histogram,
    this.hlc,
    this.hollowcandlestick,
    this.ikh,
    this.item,
    this.keltnerchannels,
    this.klinger,
    this.line,
    this.linearregression,
    this.linearregressionangle,
    this.linearregressionintercept,
    this.linearregressionslope,
    this.lollipop,
    this.macd,
    this.map,
    this.mapbubble,
    this.mapline,
    this.mappoint,
    this.mfi,
    this.momentum,
    this.natr,
    this.networkgraph,
    this.obv,
    this.ohlc,
    this.organization,
    this.packedbubble,
    this.pareto,
    this.pc,
    this.pictorial,
    this.pie,
    this.pivotpoints,
    this.pointandfigure,
    this.polygon,
    this.ppo,
    this.priceenvelopes,
    this.psar,
    this.pyramid,
    this.pyramid3d,
    this.renko,
    this.roc,
    this.rsi,
    this.sankey,
    this.scatter,
    this.scatter3d,
    this.series,
    this.slowstochastic,
    this.sma,
    this.solidgauge,
    this.spline,
    this.stochastic,
    this.streamgraph,
    this.sunburst,
    this.supertrend,
    this.tema,
    this.tiledwebmap,
    this.tilemap,
    this.timeline,
    this.treegraph,
    this.treemap,
    this.trendline,
    this.trix,
    this.variablepie,
    this.variwide,
    this.vbp,
    this.vector,
    this.venn,
    this.vwap,
    this.waterfall,
    this.williamsr,
    this.windbarb,
    this.wma,
    this.wordcloud,
    this.xrange,
    this.zigzag});