contour property

HighchartsContourSeriesOptions? contour
getter/setter pair

A contour plot is a graphical representation of three-dimensional data

Configuration options for the series are given in three levels:

  1. Options for all series in a chart are defined in the plotOptions.series object.
  2. Options for all contour series are defined in plotOptions.contour.
  3. Options for one single series are given in the series instance array.

API Docs: https://api.highcharts.com/highcharts/plotOptions.contour

Implementation

HighchartsContourSeriesOptions? contour;