treegraph property
A treegraph series is a diagram, which shows a relation between ancestors and descendants with a clear parent - child relation. The best examples of the dataStructures, which best reflect this chart are e.g. genealogy tree or directory structure.
Configuration options for the series are given in three levels:
- Options for all series in a chart are defined in the plotOptions.series object.
- Options for all
treegraphseries are defined in plotOptions.treegraph. - Options for one single series are given in the series instance array.
API Docs: https://api.highcharts.com/highcharts/plotOptions.treegraph
Implementation
HighchartsTreegraphSeriesOptions? treegraph;