textPath property

HighchartsSeriesDataLabelsTextPathOptions? textPath
getter/setter pair

Options for a label text which should follow marker's shape. Border and background are disabled for a label that follows a path.

Note: Only SVG-based renderer supports this option. Setting useHTML to true will disable this option.

Text path support is not bundled into highcharts.js, and requires the modules/textpath.js file. However, it is included in the script files of those series types that use it by default.

API Docs: https://api.highcharts.com/highcharts/series.tilemap.data.dataLabels.textPath

Implementation

HighchartsSeriesDataLabelsTextPathOptions? textPath;