HighchartsTooltipHeaderOptions class
Options for the tooltip header when tooltip.split is enabled. The header is the box containing the X value in a split tooltip.
API Docs: https://api.highcharts.com/highcharts/tooltip.header
- Inheritance
-
- Object
- HighchartsOptionsBase
- HighchartsTooltipHeaderOptions
Constructors
Properties
- backgroundColor ↔ String?
-
Background color for the tooltip header when
tooltip.split is enabled.
getter/setter pair
- borderColor ↔ String?
-
Border color for the tooltip header when
tooltip.split is enabled.
getter/setter pair
- borderWidth ↔ double?
-
The width of the border for the tooltip header when
tooltip.split is enabled.
getter/setter pair
- distance ↔ double?
-
Distance between the plot area and the header (except the
chevron) in a split tooltip, in pixels. The default value makes
the header text align with the axis labels.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape ↔ String?
-
The name of a symbol to use for the border around the tooltip
header. Applies only when tooltip.split is
enabled.
getter/setter pair
- style ↔ dynamic
-
CSS styles for the tooltip header. The default is
{ fontSize: '1em' }, ensuring that the header text is the same size as the axis labels.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJSON(
) → String -
Serializes the settings to a JSON string.
inherited
-
toOptionsJSON(
StringBuffer buffer) → void -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited