borderWidth property
The width of the border for the tooltip header when tooltip.split is enabled.
API Docs: https://api.highcharts.com/highcharts/tooltip.header.borderWidth
Implementation
double? borderWidth;
The width of the border for the tooltip header when tooltip.split is enabled.
API Docs: https://api.highcharts.com/highcharts/tooltip.header.borderWidth
double? borderWidth;