shape property

String? shape
getter/setter pair

The name of a symbol to use for the border around the tooltip header. Applies only when tooltip.split is enabled.

Custom callbacks for symbol path generation can also be added to Highcharts.SVGRenderer.prototype.symbols the same way as for series.marker.symbol.

API Docs: https://api.highcharts.com/highcharts/tooltip.header.shape

Implementation

String? shape;