options/highcharts_tooltip_options library

Classes

HighchartsTooltipAnimationOptions
Enable or disable animation of the tooltip.
HighchartsTooltipDateTimeLabelFormatsOptions
For series on datetime axes, the date format in the tooltip's header will by default be guessed based on the closest data points. This member gives the default string representations used for each unit. For an overview of the string or object configuration, see dateFormat.
HighchartsTooltipHeaderOptions
Options for the tooltip header when tooltip.split is enabled. The header is the box containing the X value in a split tooltip.
HighchartsTooltipOptions
Options for the tooltip that appears when the user hovers over a series or point.
HighchartsTooltipPositionOptions
Positioning options for fixed tooltip, taking effect only when tooltip.fixed is true.
HighchartsTooltipStyleOptions
CSS styles for the tooltip. The tooltip can also be styled through the CSS class .highcharts-tooltip.