align property
Defines the horizontal alignment of the stack total label. Can be
one of "left", "center" or "right". The default value is
calculated at runtime and depends on orientation and whether the
stack is positive or negative.
API Docs: https://api.highcharts.com/highcharts/yAxis.stackLabels.align
Implementation
String? align;