textAlign property
The text alignment for the label. While align determines where
the texts anchor point is placed with regards to the stack,
textAlign determines how the text is aligned against its anchor
point. Possible values are "left", "center" and "right".
The default value is calculated at runtime and depends on
orientation and whether the stack is positive or negative.
API Docs: https://api.highcharts.com/highcharts/yAxis.stackLabels.textAlign
Implementation
String? textAlign;