HighchartsCallback class Utilities

Callback wrap of Dart and JavaScript callbacks for Highcharts widgets.

Constructors

HighchartsCallback(HighchartsCallbackDart? dart, [String? javaScript, String? callbackKey])

Properties

callbackKey ↔ String
Key to identify the callback in the registry.
latefinal
dart → HighchartsCallbackDart?
Dart-based function to be called.
final
hashCode → int
The hash code for this object.
no setterinherited
javaScript → String?
JavaScript-based function code to be called.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register() → void
Registers a Dart-based callback to be called via 'highcharts_flutter_channel.postMessage'.
toJSON() → String
Serialises the callback for Highcharts.
toString() → String
A string representation of this object.
inherited
unregister() → void
Unregisters a Dart-based callback from been called via 'highcharts_flutter_channel.postMessage'.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

registry → Map<String, HighchartsCallbackDart>
Registry of callback
final