dataTable property
Options for a specific series-level data table or an array of data
tables. The dataTable option can be either a configuration object or an
instance of the DataTable class. If a DataTable instance is passed,
it will be used directly. If a configuration object or an array is
passed, a new DataTable instance will be created based on the provided
configuration.
API Docs: https://api.highcharts.com/highcharts/series.boxplot.dataTable
Implementation
List<dynamic>? dataTable;