options/highcharts_box_plot_series_tooltip_options
library
Classes
-
HighchartsBoxPlotSeriesTooltipOptions
-
Highcharts Options Widget.
-
HighchartsTooltipDateTimeLabelFormatsOptions
-
For series on datetime axes, the date format in the tooltip's
header will by default be guessed based on the closest data points.
This member gives the default string representations used for
each unit. For an overview of the string or object configuration, see
dateFormat.
-
Options for the tooltip header when tooltip.split
is enabled. The header is the box containing the X value in a split
tooltip.
-
HighchartsTooltipPositionOptions
-
Positioning options for fixed tooltip, taking effect only when
tooltip.fixed is
true.