options/highcharts_data_table_options library
Classes
- HighchartsDataTableOptions
-
Options for one or many chart-level data tables. The
dataTableoption, or its array members, can be either configuration objects or instances of theDataTableclass. If aDataTableinstance is passed, it will be used directly. If a configuration object is passed, a newDataTableinstance will be created based on the provided configuration.