HighchartsDataTableOptions constructor
HighchartsDataTableOptions({
- dynamic columns,
- String? id,
Options for one or many chart-level data tables. The dataTable option, or its array members, can be either configuration objects or instances of the DataTable class. If a DataTable instance is passed, it will be used directly. If a configuration object is passed, a new DataTable instance will be created based on the provided configuration.
Implementation
HighchartsDataTableOptions({this.columns, this.id});