columns property

dynamic columns
getter/setter pair

A collection of data table columns defined by a object where the key is the column ID and the value is an array of the column values. Typed arrays are supported.

API Docs: https://api.highcharts.com/highcharts/dataTable.columns

Implementation

dynamic columns;