options/highcharts_navigation_options
library
Classes
-
HighchartsAnnotationsAnimationOptions
-
Enable or disable the initial animation when a series is
displayed for the
annotation. The animation can also be set
as a configuration object. Please note that this option only
applies to the initial animation.
For other animations, see chart.animation
and the animation parameter under the API methods.
The following properties are supported:
-
HighchartsAnnotationsControlPointOptions
-
Options for annotation's control points. Each control point
inherits options from controlPointOptions object.
Options from the controlPointOptions can be overwritten
by options in a specific control point.
-
HighchartsAnnotationsControlPointStyleOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsEventsOptions
-
Events available in annotations.
-
HighchartsAnnotationsLabelAccessibilityOptions
-
Accessibility options for an annotation label.
-
HighchartsAnnotationsLabelOptions
-
Options for annotation's labels. Each label inherits options
from the labelOptions object. An option from the labelOptions
can be overwritten by config for a specific label.
-
HighchartsAnnotationsLabelsControlPointsOptions
-
The array of control points.
-
HighchartsAnnotationsLabelsOptions
-
An array of labels for the annotation. For options that apply
to multiple labels, they can be added to the
labelOptions.
-
HighchartsAnnotationsShapeOptions
-
Options for annotation's shapes. Each shape inherits options
from the shapeOptions object. An option from the shapeOptions
can be overwritten by config for a specific shape.
-
HighchartsAnnotationsShapesControlPointsOptions
-
The array of control points.
-
HighchartsAnnotationsShapesOptions
-
An array of shapes for the annotation. For options that apply
to multiple shapes, then can be added to the
shapeOptions.
-
HighchartsAnnotationsShapesPointOptions
-
This option defines the point to which the shape will be
connected. It can be either the point which exists in the
series - it is referenced by the point's id - or a new point
with defined x, y properties and optionally axes.
-
HighchartsAnnotationsShapesPointsOptions
-
An array of points for the shape
or a callback function that returns that shape point.
-
HighchartsAnnotationsTypeBackgroundOptions
-
Background shape options for the annotation.
-
HighchartsAnnotationsTypeLineOptions
-
Line options.
-
HighchartsAnnotationsTypeOptions
-
Additional options for an annotation with the type.
-
HighchartsAnnotationsTypesCrookedLineControlPointOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesCrookedLineLabelOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesCrookedLineOptions
-
Options for the crooked line annotation type.
-
HighchartsAnnotationsTypesCrookedLineTypeLineOptions
-
Line options.
-
HighchartsAnnotationsTypesCrookedLineTypeOptions
-
Additional options for an annotation with the type.
-
HighchartsAnnotationsTypesCrookedLineTypePointsOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesElliottWaveLabelOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesElliottWaveLabelStyleOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesElliottWaveOptions
-
Options for the elliott wave annotation type.
-
HighchartsAnnotationsTypesElliottWaveTypeLineOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesElliottWaveTypeOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesElliottWaveTypePointsLabelOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesElliottWaveTypePointsOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesFibonacciLabelOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesFibonacciLabelStyleOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesFibonacciOptions
-
Options for the fibonacci annotation type.
-
HighchartsAnnotationsTypesFibonacciTimeZonesOptions
-
Options for the fibonacci time zones annotation type.
-
HighchartsAnnotationsTypesFibonacciTimeZonesTypeControlPointOptionsOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesFibonacciTimeZonesTypeLineOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesFibonacciTimeZonesTypeOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesFibonacciTypeLabelsOptions
-
An array with options for the labels.
-
HighchartsAnnotationsTypesFibonacciTypeOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesInfinityLineOptions
-
Options for the infinity line annotation type.
-
HighchartsAnnotationsTypesMeasureControlPointOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesMeasureOptions
-
Options for the measure annotation type.
-
HighchartsAnnotationsTypesMeasureTypeBackgroundOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesMeasureTypeCrosshairXOptions
-
Configure a crosshair that is horizontally placed in middle of
rectangle.
-
HighchartsAnnotationsTypesMeasureTypeCrosshairYOptions
-
Configure a crosshair that is vertically placed in middle of
rectangle.
-
HighchartsAnnotationsTypesMeasureTypeLabelOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesMeasureTypeLabelStyleOptions
-
CSS styles for the measure label.
-
HighchartsAnnotationsTypesMeasureTypeOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesOptions
-
Option override for specific advanced annotation types. This collection
is intended for general theming using
Highcharts.setOptions().
-
HighchartsAnnotationsTypesPitchforkOptions
-
Options for the pitchfork annotation type.
-
HighchartsAnnotationsTypesPitchforkTypeInnerBackgroundOptions
-
Inner background options.
-
HighchartsAnnotationsTypesPitchforkTypeOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesPitchforkTypeOuterBackgroundOptions
-
Outer background options.
-
HighchartsAnnotationsTypesTimeCyclesOptions
-
Options for the time cycles annotation type.
-
HighchartsAnnotationsTypesTimeCyclesTypeOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesTunnelControlPointOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesTunnelOptions
-
Options for the tunnel annotation type.
-
HighchartsAnnotationsTypesTunnelTypeBackgroundOptions
-
Background options.
-
HighchartsAnnotationsTypesTunnelTypeHeightControlPointOptions
-
Options for the control point which controls
the annotation's height.
-
HighchartsAnnotationsTypesTunnelTypeLineOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesTunnelTypeOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesVerticalLineLabelOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesVerticalLineLabelStyleOptions
-
Highcharts Options Widget.
-
HighchartsAnnotationsTypesVerticalLineOptions
-
Options for the vertical line annotation type.
-
HighchartsAnnotationsTypesVerticalLineTypeConnectorOptions
-
Connector options.
-
HighchartsAnnotationsTypesVerticalLineTypeLabelOptions
-
Label options.
-
HighchartsAnnotationsTypesVerticalLineTypeOptions
-
Highcharts Options Widget.
-
HighchartsNavigationAnnotationsOptions
-
Additional options to be merged into all annotations.
-
HighchartsNavigationBindingsArrowInfinityLineAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsArrowInfinityLineOptions
-
A line with arrow annotation. Includes
start and one event in steps
array.
-
HighchartsNavigationBindingsArrowRayAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsArrowRayOptions
-
A ray with an arrow annotation bindings. Includes
start and one event
in steps array.
-
HighchartsNavigationBindingsArrowSegmentAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsArrowSegmentOptions
-
A segment with an arrow annotation bindings. Includes
start and one
event in steps array.
-
HighchartsNavigationBindingsCrooked3AnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsCrooked3Options
-
Crooked line (three points) annotation bindings. Includes
start and two
events in steps (for second and third points in crooked line) array.
-
HighchartsNavigationBindingsCrooked5AnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsCrooked5Options
-
Crooked line (five points) annotation bindings. Includes
start and four
events in steps (for all consequent points in crooked line) array.
-
HighchartsNavigationBindingsElliott3AnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsElliott3Options
-
Elliott wave (three points) annotation bindings. Includes
start and two
events in steps (for second and third points) array.
-
HighchartsNavigationBindingsElliott5AnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsElliott5Options
-
Elliott wave (five points) annotation bindings. Includes
start and four
event in steps (for all consequent points in Elliott wave) array.
-
HighchartsNavigationBindingsFibonacciAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsFibonacciOptions
-
A fibonacci annotation bindings. Includes
start and two events in
steps array (updates second point, then height).
-
HighchartsNavigationBindingsFibonacciTimeZonesAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsFibonacciTimeZonesOptions
-
The Fibonacci Time Zones annotation bindings. Includes
start and one
event in steps array.
-
HighchartsNavigationBindingsHorizontalLineAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsHorizontalLineOptions
-
A horizontal line annotation. Includes
start event.
-
HighchartsNavigationBindingsInfinityLineAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsInfinityLineOptions
-
A line annotation. Includes
start and one event in steps array.
-
HighchartsNavigationBindingsMeasureXAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsMeasureXOptions
-
A measure (x-dimension) annotation bindings. Includes
start and one
event in steps array.
-
HighchartsNavigationBindingsMeasureXYAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsMeasureXYOptions
-
A measure (xy-dimension) annotation bindings. Includes
start and one
event in steps array.
-
HighchartsNavigationBindingsMeasureYAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsMeasureYOptions
-
A measure (y-dimension) annotation bindings. Includes
start and one
event in steps array.
-
HighchartsNavigationBindingsOptions
-
Highcharts Options Widget.
-
HighchartsNavigationBindingsParallelChannelAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsParallelChannelOptions
-
A parallel channel (tunnel) annotation bindings. Includes
start and
two events in steps array (updates second point, then height).
-
HighchartsNavigationBindingsPitchforkAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsPitchforkOptions
-
An Andrew's pitchfork annotation bindings. Includes
start and two
events in steps array (sets second and third control points).
-
HighchartsNavigationBindingsRayAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsRayOptions
-
A ray annotation bindings. Includes
start and one event in steps
array.
-
HighchartsNavigationBindingsSegmentAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsSegmentOptions
-
A segment annotation bindings. Includes
start and one event in steps
array.
-
HighchartsNavigationBindingsTimeCyclesAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsTimeCyclesOptions
-
A time cycles annotation bindings. Includes
start event and 1 step
event. first click marks the beginning of the circle, and the second one
sets its diameter.
-
HighchartsNavigationBindingsVerticalArrowAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsVerticalArrowOptions
-
A vertical arrow annotation bindings. Includes
start event. On click,
finds the closest point and marks it with an arrow.
var(--highcharts-positive-color) is the color of the arrow when
pointing from above and var(--highcharts-negative-color)
when pointing from below the point.
-
HighchartsNavigationBindingsVerticalCounterAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsVerticalCounterOptions
-
A vertical counter annotation bindings. Includes
start event. On click,
finds the closest point and marks it with a numeric annotation -
incrementing counter on each add.
-
HighchartsNavigationBindingsVerticalLabelAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsVerticalLabelOptions
-
Highcharts Options Widget.
-
HighchartsNavigationBindingsVerticalLineAnnotationsOptions
-
Options to customize the bindings' annotation shapes and labels.
-
HighchartsNavigationBindingsVerticalLineAnnotationsTypesFibonacciTimeZonesTypeOptionsPointsOptions
-
Highcharts Options Widget.
-
HighchartsNavigationBindingsVerticalLineAnnotationsTypesTimeCyclesTypeOptionsPointsOptions
-
Highcharts Options Widget.
-
HighchartsNavigationBindingsVerticalLineOptions
-
A vertical line annotation. Includes
start event.
-
HighchartsNavigationBreadcrumbsButtonThemeOptions
-
A collection of attributes for the buttons. The object takes SVG
attributes like
fill, stroke, stroke-width, as well as style,
a collection of CSS properties for the text.
-
HighchartsNavigationBreadcrumbsButtonThemeStyleOptions
-
Highcharts Options Widget.
-
HighchartsNavigationBreadcrumbsEventsOptions
-
Highcharts Options Widget.
-
HighchartsNavigationBreadcrumbsOptions
-
Options for breadcrumbs. Breadcrumbs general options are defined in
navigation.breadcrumbs. Specific options for drilldown are set in
drilldown.breadcrumbs and for tree-like series traversing, in
plotOptions[series].breadcrumbs.
-
HighchartsNavigationBreadcrumbsPositionOptions
-
Positioning for the button row. The breadcrumbs buttons will be
aligned properly for the default chart layout (title, subtitle,
legend, range selector) for the custom chart layout set the position
properties.
-
HighchartsNavigationBreadcrumbsSeparatorOptions
-
Options object for Breadcrumbs separator.
-
HighchartsNavigationBreadcrumbsSeparatorStyleOptions
-
CSS styles for the breadcrumbs separator.
-
HighchartsNavigationButtonOptions
-
A collection of options for buttons appearing in the exporting
module.
-
HighchartsNavigationButtonThemeOptions
-
A configuration object for the button theme. The object accepts
SVG properties like
stroke-width, stroke and fill.
Tri-state button styles are supported by the states.hover and
states.select objects.
-
HighchartsNavigationButtonThemeStatesOptions
-
Tri-state button styles.
-
HighchartsNavigationEventsOptions
-
Events to communicate between Stock Tools and custom GUI.
-
HighchartsNavigationOptions
-
A collection of options for buttons and menus appearing in the exporting
module or in Stock Tools.