contour property
A contour plot is a graphical representation of three-dimensional data
Configuration options for the series are given in three levels:
- Options for all series in a chart are defined in the plotOptions.series object.
- Options for all
contourseries are defined in plotOptions.contour. - Options for one single series are given in the series instance array.
API Docs: https://api.highcharts.com/highcharts/plotOptions.contour
Implementation
HighchartsContourSeriesOptions? contour;