distance property
Distance between the plot area and the header (except the chevron) in a split tooltip, in pixels. The default value makes the header text align with the axis labels.
API Docs: https://api.highcharts.com/highcharts/tooltip.header.distance
Implementation
double? distance;